@@ -94,7 +94,10 @@ class MainOptionsDialog(gtk.Dialog):
 class CreateEngine(gtk.Dialog):
    def __init__(self, widget):
       gtk.Dialog.__init__(self, "Create engine", None)
-      ok_button = self.add_button(gtk.STOCK_OK, gtk.RESPONSE_OK)
+      ok_button = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+      ok_button.set_title("OK")
+      ok_button.set_style(hildon.BUTTON_STYLE_PICKER)
+      self.action_area.pack_start(ok_button, False, False, 0)
       
       self.osso_context = osso.Context("org.touchsearch.touchsearch", "3.0", False)
       self.osso_rpc = osso.Rpc(self.osso_context)
@@ -193,6 +196,8 @@ class CreateEngine(gtk.Dialog):
       dialog.run()
       dialog.destroy()
       
+      if retcode == 0: self.destroy()
+      
       print retcode
       print error
       print name
@@ -240,6 +245,7 @@ class SettingsDialog(gtk.Dialog):
       adjustment.set_property("value", settings.get_opacity())
       
       picker = hildon.PickerButton(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL)
+      picker.set_size_request(300, 70)
       selector = hildon.TouchSelector(text=True)
       selector.set_column_selection_mode(hildon.TOUCH_SELECTOR_SELECTION_MODE_MULTIPLE)
       ie = InstalledEngines()
@@ -522,7 +528,7 @@ class AboutDialog(gtk.AboutDialog):
       gtk.AboutDialog.__init__(self)
       self.set_title("About")
       self.set_name("TouchSearch")
-      self.set_version("3.1")
+      self.set_version("3.2")
       self.set_copyright("Copyright 2009, 2010 Brent Chiodo")
       self.set_authors(["Brent Chiodo <bchiodo@gmail.com>"])
       self.set_logo(gtk.gdk.pixbuf_new_from_file("/opt/touchsearch/icons/icon.png"))
