@@ -30,6 +30,10 @@ if not os.path.exists(se_file):
    data = open(se_file, 'w')
    cPickle.dump(default, data)
    data.close()
+   
+chrome_dir = '%s/.mozilla/microb/chrome/' % HOME
+if not os.path.exists(chrome_dir):
+   os.mkdir(chrome_dir)
 
 css_file = '%s/.mozilla/microb/chrome/userContent.css' % HOME
 if not os.path.exists(css_file):
